Citation Guidelines
===================

|JOSS| |Birrer&Amara|

If you use lenstronomy for work or research presented in a publication (whether
directly, or as a dependency of another package) we recommend and encourage
the following acknowledgment:

  This research made use of lenstronomy, a multi-purpose gravitational lens
  modeling software package (Birrer et. al., 2021, Birrer & Amara, 2018).

where the citations are to our publication in the `Journal of Open Source
Software`_ and the `Original Publication`_. We also encourage citations within the main text wherever
appropriate. DOIs and BibTeX keys are available through the links above.

Please also cite `Birrer et al 2015 <http://adsabs.harvard.edu/abs/2015ApJ...813..102B>`_
when you make use of the lenstronomy work-flow or the Shapelet source reconstruction and make sure to cite also
the relevant work that was implemented in lenstronomy, as described in the release paper and the documentation.
Don't hesitate to reach out to the developers if you have questions!


.. _Journal of Open Source Software: https://joss.theoj.org/papers/10.21105/joss.03283
.. _Original Publication: https://ui.adsabs.harvard.edu/abs/2018PDU....22..189B/abstract

.. |JOSS| image:: https://joss.theoj.org/papers/10.21105/joss.03283/status.svg
    :target: https://joss.theoj.org/papers/10.21105/joss.03283

.. |Birrer&Amara| image:: https://img.shields.io/badge/arXiv-1803.09746%20-yellowgreen.svg
    :target: https://ui.adsabs.harvard.edu/abs/2018PDU....22..189B/abstract